# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.rdf.blank_node import BlankNode as BlankNode
from .._pyi.rdf.literal import Literal as Literal
from .._pyi.rdf.parse_exception import ParseException as ParseException
from .._pyi.rdf.query_exception import QueryException as QueryException
from .._pyi.rdf.repository import Repository as Repository
from .._pyi.rdf.repository_exception import RepositoryException as RepositoryException
from .._pyi.rdf.statement import Statement as Statement
from .._pyi.rdf.uri import URI as URI
from .._pyi.rdf.x_blank_node import XBlankNode as XBlankNode
from .._pyi.rdf.x_document_metadata_access import XDocumentMetadataAccess as XDocumentMetadataAccess
from .._pyi.rdf.x_document_repository import XDocumentRepository as XDocumentRepository
from .._pyi.rdf.x_literal import XLiteral as XLiteral
from .._pyi.rdf.x_metadatable import XMetadatable as XMetadatable
from .._pyi.rdf.x_named_graph import XNamedGraph as XNamedGraph
from .._pyi.rdf.x_node import XNode as XNode
from .._pyi.rdf.x_query_select_result import XQuerySelectResult as XQuerySelectResult
from .._pyi.rdf.x_reified_statement import XReifiedStatement as XReifiedStatement
from .._pyi.rdf.x_repository import XRepository as XRepository
from .._pyi.rdf.x_repository_supplier import XRepositorySupplier as XRepositorySupplier
from .._pyi.rdf.x_resource import XResource as XResource
from .._pyi.rdf.xuri import XURI as XURI



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.table
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class TableBorderDistances(object):
    """
    Struct Class

    contains the distance settings of the border lines of all cells in a cell range.
    
    In a queried structure, the flags in TableBorderDistances.Is...DistanceValid indicate that not all lines of the boxes have the same values.
    
    In a structure which is used for setting, these flags determine if the corresponding distance should be set or if the old value should be kept.

    See Also:
        `API TableBorderDistances <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1table_1_1TableBorderDistances.html>`_
    """
    typeName: Literal['com.sun.star.table.TableBorderDistances']

    def __init__(self, TopDistance: typing.Optional[int] = ..., IsTopDistanceValid: typing.Optional[bool] = ..., BottomDistance: typing.Optional[int] = ..., IsBottomDistanceValid: typing.Optional[bool] = ..., LeftDistance: typing.Optional[int] = ..., IsLeftDistanceValid: typing.Optional[bool] = ..., RightDistance: typing.Optional[int] = ..., IsRightDistanceValid: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            TopDistance (int, optional): TopDistance value.
            IsTopDistanceValid (bool, optional): IsTopDistanceValid value.
            BottomDistance (int, optional): BottomDistance value.
            IsBottomDistanceValid (bool, optional): IsBottomDistanceValid value.
            LeftDistance (int, optional): LeftDistance value.
            IsLeftDistanceValid (bool, optional): IsLeftDistanceValid value.
            RightDistance (int, optional): RightDistance value.
            IsRightDistanceValid (bool, optional): IsRightDistanceValid value.
        """


    @property
    def TopDistance(self) -> int:
        """
        contains the distance between the top lines and other contents.
        """


    @property
    def IsTopDistanceValid(self) -> bool:
        """
        specifies whether the value of TableBorder.TopDistance is used.
        """


    @property
    def BottomDistance(self) -> int:
        """
        contains the distance between the bottom lines and other contents.
        """


    @property
    def IsBottomDistanceValid(self) -> bool:
        """
        specifies whether the value of TableBorder.BottomDistance is used.
        """


    @property
    def LeftDistance(self) -> int:
        """
        contains the distance between the left lines and other contents.
        """


    @property
    def IsLeftDistanceValid(self) -> bool:
        """
        specifies whether the value of TableBorder.LeftDistance is used.
        """


    @property
    def RightDistance(self) -> int:
        """
        contains the distance between the right lines and other contents.
        """


    @property
    def IsRightDistanceValid(self) -> bool:
        """
        specifies whether the value of TableBorder.RightDistance is used.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.script.vba
from typing_extensions import Literal
"""
Const

Constants used to identify VBA document events.

If one of these events is fired, a specific VBA macro in a specific document code module will be executed.

Each event expects some specific arguments to be passed to XVBAEventProcessor.processVbaEvent().

See Also:
    `API VBAEventId <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1script_1_1vba_1_1VBAEventId.html>`_
"""
NO_EVENT: Literal[-1]
"""
An identifier not corresponding to any VBA document event.
"""
AUTO_NEW: Literal[1]
"""
New document opened from template.

No arguments.
"""
AUTO_OPEN: Literal[2]
"""
Document opened (loaded).

No arguments.
"""
AUTO_CLOSE: Literal[3]
"""
Document about to be closed.

No arguments.
"""
AUTO_EXEC: Literal[4]
"""
Application start.

No arguments.
"""
AUTO_EXIT: Literal[5]
"""
Application exit.

No arguments.
"""
DOCUMENT_NEW: Literal[1001]
"""
New text document opened from template.

No arguments.
"""
DOCUMENT_OPEN: Literal[1002]
"""
Text document opened (loaded).

No arguments.
"""
DOCUMENT_CLOSE: Literal[1003]
"""
Document about to be closed.

No arguments.
"""
WORKBOOK_ACTIVATE: Literal[2001]
"""
Document activated.

No arguments.
"""
WORKBOOK_DEACTIVATE: Literal[2002]
"""
Document deactivated.

No arguments.
"""
WORKBOOK_OPEN: Literal[2003]
"""
Document opened (loaded).

No arguments.
"""
WORKBOOK_BEFORECLOSE: Literal[2004]
"""
Document about to be closed.

Arguments: [out] boolean bCancel.
"""
WORKBOOK_BEFOREPRINT: Literal[2005]
"""
Document about to be printed.

Arguments: [out] boolean bCancel.
"""
WORKBOOK_BEFORESAVE: Literal[2006]
"""
Document about to be saved.

Arguments: boolean bSaveAs, [out] boolean bCancel.
"""
WORKBOOK_AFTERSAVE: Literal[2007]
"""
Document has been saved.

Arguments: boolean bSuccess.
"""
WORKBOOK_NEWSHEET: Literal[2008]
"""
New sheet inserted.

Arguments: short nSheet.
"""
WORKBOOK_WINDOWACTIVATE: Literal[2009]
"""
Document window has been activated.

Arguments: XController aController.
"""
WORKBOOK_WINDOWDEACTIVATE: Literal[2010]
"""
Document window has been deactivated.

Arguments: XController aController.
"""
WORKBOOK_WINDOWRESIZE: Literal[2011]
"""
Document window has been resized.

Arguments: XController aController.
"""
WORKSHEET_ACTIVATE: Literal[2101]
"""
Worksheet has been activated (made visible).

Arguments: short nSheet.
"""
WORKSHEET_DEACTIVATE: Literal[2102]
"""
Worksheet has been activated (made visible).

Arguments: short nSheet.
"""
WORKSHEET_BEFOREDOUBLECLICK: Literal[2103]
"""
Double click in the sheet.

Arguments: XRange/XSheetCellRangeContainer aRange, [out] boolean bCancel.
"""
WORKSHEET_BEFORERIGHTCLICK: Literal[2104]
"""
Right click in the sheet.

Arguments: XRange/XSheetCellRangeContainer aRange, [out] boolean bCancel.
"""
WORKSHEET_CALCULATE: Literal[2105]
"""
Cells in sheet have been recalculated.

Arguments: short nSheet.
"""
WORKSHEET_CHANGE: Literal[2106]
"""
Cells in sheet have been changed.

Arguments: XRange/XSheetCellRangeContainer aRange.
"""
WORKSHEET_SELECTIONCHANGE: Literal[2107]
"""
Selection in sheet has been changed.

Arguments: XRange/XSheetCellRangeContainer aRange.
"""
WORKSHEET_FOLLOWHYPERLINK: Literal[2108]
"""
Hyperlink has been clicked.

Arguments: XCell aCell.
"""
USERDEFINED_START: Literal[1000000]
"""
Implementations are allowed to use identifiers above this value for any internal purpose.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.beans.ambiguous import Ambiguous as Ambiguous
from .._pyi.beans.defaulted import Defaulted as Defaulted
from .._pyi.beans.get_direct_property_tolerant_result import GetDirectPropertyTolerantResult as GetDirectPropertyTolerantResult
from .._pyi.beans.get_property_tolerant_result import GetPropertyTolerantResult as GetPropertyTolerantResult
from .._pyi.beans.illegal_type_exception import IllegalTypeException as IllegalTypeException
from .._pyi.beans.introspection import Introspection as Introspection
from .._pyi.beans.introspection_exception import IntrospectionException as IntrospectionException
from .._pyi.beans.named_value import NamedValue as NamedValue
from .._pyi.beans.not_removeable_exception import NotRemoveableException as NotRemoveableException
from .._pyi.beans.optional import Optional as Optional
from .._pyi.beans.pair import Pair as Pair
from .._pyi.beans.property import Property as Property
from .._pyi.beans.property_bag import PropertyBag as PropertyBag
from .._pyi.beans.property_change_event import PropertyChangeEvent as PropertyChangeEvent
from .._pyi.beans.property_exist_exception import PropertyExistException as PropertyExistException
from .._pyi.beans.property_set import PropertySet as PropertySet
from .._pyi.beans.property_set_info_change_event import PropertySetInfoChangeEvent as PropertySetInfoChangeEvent
from .._pyi.beans.property_state_change_event import PropertyStateChangeEvent as PropertyStateChangeEvent
from .._pyi.beans.property_value import PropertyValue as PropertyValue
from .._pyi.beans.property_values import PropertyValues as PropertyValues
from .._pyi.beans.property_veto_exception import PropertyVetoException as PropertyVetoException
from .._pyi.beans.set_property_tolerant_failed import SetPropertyTolerantFailed as SetPropertyTolerantFailed
from .._pyi.beans.string_pair import StringPair as StringPair
from .._pyi.beans.unknown_property_exception import UnknownPropertyException as UnknownPropertyException
from .._pyi.beans.x_exact_name import XExactName as XExactName
from .._pyi.beans.x_fast_property_set import XFastPropertySet as XFastPropertySet
from .._pyi.beans.x_hierarchical_property_set import XHierarchicalPropertySet as XHierarchicalPropertySet
from .._pyi.beans.x_hierarchical_property_set_info import XHierarchicalPropertySetInfo as XHierarchicalPropertySetInfo
from .._pyi.beans.x_introspection import XIntrospection as XIntrospection
from .._pyi.beans.x_introspection_access import XIntrospectionAccess as XIntrospectionAccess
from .._pyi.beans.x_material_holder import XMaterialHolder as XMaterialHolder
from .._pyi.beans.x_multi_hierarchical_property_set import XMultiHierarchicalPropertySet as XMultiHierarchicalPropertySet
from .._pyi.beans.x_multi_property_set import XMultiPropertySet as XMultiPropertySet
from .._pyi.beans.x_multi_property_states import XMultiPropertyStates as XMultiPropertyStates
from .._pyi.beans.x_properties_change_listener import XPropertiesChangeListener as XPropertiesChangeListener
from .._pyi.beans.x_properties_change_notifier import XPropertiesChangeNotifier as XPropertiesChangeNotifier
from .._pyi.beans.x_property import XProperty as XProperty
from .._pyi.beans.x_property_access import XPropertyAccess as XPropertyAccess
from .._pyi.beans.x_property_bag import XPropertyBag as XPropertyBag
from .._pyi.beans.x_property_change_listener import XPropertyChangeListener as XPropertyChangeListener
from .._pyi.beans.x_property_container import XPropertyContainer as XPropertyContainer
from .._pyi.beans.x_property_set import XPropertySet as XPropertySet
from .._pyi.beans.x_property_set_info import XPropertySetInfo as XPropertySetInfo
from .._pyi.beans.x_property_set_info_change_listener import XPropertySetInfoChangeListener as XPropertySetInfoChangeListener
from .._pyi.beans.x_property_set_info_change_notifier import XPropertySetInfoChangeNotifier as XPropertySetInfoChangeNotifier
from .._pyi.beans.x_property_set_option import XPropertySetOption as XPropertySetOption
from .._pyi.beans.x_property_state import XPropertyState as XPropertyState
from .._pyi.beans.x_property_state_change_listener import XPropertyStateChangeListener as XPropertyStateChangeListener
from .._pyi.beans.x_property_with_state import XPropertyWithState as XPropertyWithState
from .._pyi.beans.x_tolerant_multi_property_set import XTolerantMultiPropertySet as XTolerantMultiPropertySet
from .._pyi.beans.x_vetoable_change_listener import XVetoableChangeListener as XVetoableChangeListener
from .._pyi.beans.the_introspection import theIntrospection as theIntrospection



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.accessibility
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .accessible_scroll_type import AccessibleScrollType as AccessibleScrollType_b426126f
    from .text_segment import TextSegment as TextSegment_1e5b0ee8
    from ..awt.point import Point as Point_5fb2085e
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class XAccessibleText(XInterface_8f010a43):
    """
    Implement this interface to give read-only access to a text.
    
    The XAccessibleText interface should be implemented by all UNO components that present textual information on the display like buttons, text entry fields, or text portions of the document window. The interface provides access to the text's content, attributes, and spatial location. However, text can not be modified with this interface. That is the task of the XAccessibleEditableText interface.
    
    The text length, i.e. the number of characters in the text, is returned by XAccessibleText.getCharacterCount(). All methods that operate on particular characters (e.g. XAccessibleText.getCharacterAt()) use character indices from 0 to length-1. All methods that operate on character positions (e.g. XAccessibleText.getTextRange()) use indices from 0 to length.
    
    Please note that accessible text does not necessarily support selection. In this case it should behave as if there where no selection. An empty selection is used for example to express the current cursor position.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessibleText <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleText.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.accessibility.XAccessibleText']

    def copyText(self, nStartIndex: int, nEndIndex: int) -> bool:
        """
        Copy the specified text into the clipboard.
        
        Copy the specified text into the clipboard. The text that is copied is the same text that would have been selected by the XAccessibleText.getTextRange() method.
        
        The other clipboard related methods XAccessibleEditableText.cutText() and XAccessibleEditableText.deleteText() can be found in the XAccessibleEditableText because of their destructive nature.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getCaretPosition(self) -> int:
        """
        Return the position of the caret.
        
        Returns the offset of the caret. The caret is often called text cursor. The caret is actually the position between two characters. Its position/offset is that of the character to the right of it.
        """
    def getCharacter(self, nIndex: int) -> str:
        """
        Return the character at the specified position.
        
        Returns the character at the given index.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getCharacterAttributes(self, nIndex: int, aRequestedAttributes: 'typing.Tuple[str, ...]') -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        Get the attribute set for the specified position.
        
        Returns a set of attributes that are associated for the character at the given index. To prevent the method from returning possibly large sets of attributes that the caller is not interested in the caller has to provide a list of attributes that he wants to be returned.
        
        An empty sequence signals the callers interest in all the attributes. This is useful in two cases: a) Simply as a way to avoid passing a potentially large array to the called object or b) when the caller does not know what attributes the called objects supports but is interested in all of them nevertheless.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
        """
    def getCharacterBounds(self, nIndex: int) -> 'Rectangle_84b109e9':
        """
        Return the bounding box of the specified position.
        
        Returns the bounding box of the indexed character.
        
        The virtual character after the last character of the represented text, i.e. the one at position length is a special case. It represents the current input position and will therefore typically be queried by AT more often than other positions. Because it does not represent an existing character its bounding box is defined in relation to preceding characters. It should be roughly equivalent to the bounding box of some character when inserted at the end of the text. Its height typically being the maximal height of all the characters in the text or the height of the preceding character, its width being at least one pixel so that the bounding box is not degenerate.
        Note that the index \"length\" is not always valid. Whether it is or not is implementation dependent. It typically is when text is editable or otherwise when on the screen the caret can be placed behind the text. You can be sure that the index is valid after you have received an AccessibleEventId.CARET event for this index.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getCharacterCount(self) -> int:
        """
        Return the number of characters in the represented text.
        
        Returns the number of characters in the text represented by this object or, in other words, the text length.
        """
    def getIndexAtPoint(self, aPoint: 'Point_5fb2085e') -> int:
        """
        Return the text position for the specified screen position.
        
        Given a point in local coordinates, i.e. relative to the coordinate system of the object, return the zero-based index of the character under that point. The same functionality could be achieved by using the bounding boxes for each character as returned by XAccessibleText.getCharacterBounds(). The method XAccessibleText.getIndexAtPoint(), however, can be implemented in a more efficient way.
        """
    def getSelectedText(self) -> str:
        """
        Return the selected text.
        
        Returns the portion of the text that is selected.
        """
    def getSelectionEnd(self) -> int:
        """
        Return the position of the end of the selection.
        
        Returns the index of the end of the selected text.
        """
    def getSelectionStart(self) -> int:
        """
        Return the position of the start of the selection.
        
        Returns the index of the start of the selected text.
        """
    def getText(self) -> str:
        """
        Return the whole text.
        
        Returns the complete text. This is equivalent to a call to XAccessibleText.getTextRange() with the arguments zero and getCharacterCount()-1.
        """
    def getTextAtIndex(self, nIndex: int, nTextType: int) -> 'TextSegment_1e5b0ee8':
        """
        Get a text portion around the given position.
        
        Returns the substring of the specified text type that contains the character at the given index, if any. For example, given the text type AccessibleTextType.WORD, the word which contains the character at position nIndex is returned, or an empty string if no word is found at the that position.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getTextBeforeIndex(self, nIndex: int, nTextType: int) -> 'TextSegment_1e5b0ee8':
        """
        Get a text portion before the given position.
        
        Returns the substring of the specified text type that is located before the given character and does not include it. The result of this method should be same as a result for XAccessibleText.getTextAtIndex() with a suitably decreased index value.
        
        For example, if text type is AccessibleTextType.WORD, then the complete word that is closest to and located before nIndex is returned.
        
        If the index is valid, but no suitable word (or other text type) is found, an empty text segment is returned.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getTextBehindIndex(self, nIndex: int, nTextType: int) -> 'TextSegment_1e5b0ee8':
        """
        Get a text portion behind the given position.
        
        Returns the substring of the specified text type that is located after the given character and does not include it. The result of this method should be same as a result for XAccessibleText.getTextAtIndex() with a suitably increased index value.
        
        For example, if text type is AccessibleTextType.WORD, then the complete word that is closest to and located behind nIndex is returned.
        
        If the index is valid, but no suitable word (or other text type) is found, an empty string is returned.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getTextRange(self, nStartIndex: int, nEndIndex: int) -> str:
        """
        Return the specified text range.
        
        Returns the substring between the two given indices.
        
        The substring starts with the character at nStartIndex (inclusive) and up to the character at nEndIndex (exclusive), if nStartIndex is less or equal nEndIndex. If nEndIndex is lower than nStartIndex, the result is the same as a call with the two arguments being exchanged.
        
        The whole text can be requested by passing the indices zero and getCharacterCount(). If both indices have the same value, an empty string is returned.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def scrollSubstringTo(self, nStartIndex: int, nEndIndex: int, aScrollType: 'AccessibleScrollType_b426126f') -> bool:
        """
        Scroll the specified text to make it visible on screen.
        
        **since**
        
            LibreOffice 7.0

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def setCaretPosition(self, nIndex: int) -> bool:
        """
        Set the position of the caret.
        
        The caret is often called text cursor. The caret is actually the position between two characters. Its position/offset is that of the character to the right of it.
        
        Setting the caret position may or may not alter the current selection. A change of the selection is notified to the accessibility event listeners with an AccessibleEventId.ACCESSIBLE_SELECTION_EVENT.
        
        When the new caret position differs from the old one (which, of course, is the standard case) this is notified to the accessibility event listeners with an AccessibleEventId.ACCESSIBLE_CARET_EVENT.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def setSelection(self, nStartIndex: int, nEndIndex: int) -> bool:
        """
        Set a new selection.
        
        Sets the selected text portion according to the given indices. The old selection is replaced by the new selection.
        
        The selection encompasses the same string of text that XAccessibleText.getTextRange() would have selected. See there for details.
        
        Setting the selection may or may not change the caret position. Typically the caret is moved to the position after the second argument. When the caret is moved this is notified to the accessibility event listeners with an AccessibleEventId.ACCESSIBLE_CARET_EVENT.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.linguistic2
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class XSpellAlternatives(XInterface_8f010a43):
    """
    Gives access to the results of failed spell checking attempts and may provide spelling alternatives.
    
    This is used by the com.sun.star.linguistic2.XSpellChecker.spell() function when the word was not found to be correct. Suggestions for other words to be used may be provided along with a failure-type that may specify why the word was not correct.

    See Also:
        `API XSpellAlternatives <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XSpellAlternatives.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.linguistic2.XSpellAlternatives']

    def getAlternatives(self) -> 'typing.Tuple[str, ...]':
        """
        """
    def getAlternativesCount(self) -> int:
        """
        """
    def getFailureType(self) -> int:
        """
        """
    def getLocale(self) -> 'Locale_70d308fa':
        """
        """
    def getWord(self) -> str:
        """
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb
from ..document.office_document import OfficeDocument as OfficeDocument_fecd0df2
from ..frame.x_loadable import XLoadable as XLoadable_989a0a7f
from ..script.provider.x_script_provider_supplier import XScriptProviderSupplier as XScriptProviderSupplier_194514a2
from .x_office_database_document import XOfficeDatabaseDocument as XOfficeDatabaseDocument_327f0f39
from ..util.x_closeable import XCloseable as XCloseable_99ee0aa8

class OfficeDatabaseDocument(OfficeDocument_fecd0df2, XLoadable_989a0a7f, XScriptProviderSupplier_194514a2, XOfficeDatabaseDocument_327f0f39, XCloseable_99ee0aa8):
    """
    Service Class

    specifies an office database document which is a storable document.
    
    These documents contain information about forms, and reports, and the properties of a data source.
    
    The database document contains no data per default. The following is stored inside the document:
    
    **since**
    
        OOo 2.0

    See Also:
        `API OfficeDatabaseDocument <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1OfficeDatabaseDocument.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal


class MessageBoxButtons(object):
    """
    Const

    defines constants for the possible message box button combinations.

    See Also:
        `API MessageBoxButtons <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1MessageBoxButtons.html>`_
    """
    BUTTONS_OK: Literal[1]
    """
    specifies a message with \"OK\" button.
    """
    BUTTONS_OK_CANCEL: Literal[2]
    """
    specifies a message box with \"OK\" and \"CANCEL\" button.
    """
    BUTTONS_YES_NO: Literal[3]
    """
    specifies a message box with \"YES\" and \"NO\" button.
    """
    BUTTONS_YES_NO_CANCEL: Literal[4]
    """
    specifies a message box with \"YES\", \"NO\" and \"CANCEL\" button.
    """
    BUTTONS_RETRY_CANCEL: Literal[5]
    """
    specifies a message box with \"RETRY\" and \"CANCEL\" button.
    """
    BUTTONS_ABORT_IGNORE_RETRY: Literal[6]
    """
    specifies a message box with \"ABORT\", \"IGNORE\" and \"RETRY\" button.
    """
    DEFAULT_BUTTON_OK: Literal[65536]
    """
    specifies that OK is the default button.
    """
    DEFAULT_BUTTON_CANCEL: Literal[131072]
    """
    specifies that CANCEL is the default button.
    """
    DEFAULT_BUTTON_RETRY: Literal[196608]
    """
    specifies that RETRY is the default button.
    """
    DEFAULT_BUTTON_YES: Literal[262144]
    """
    specifies that YES is the default button.
    """
    DEFAULT_BUTTON_NO: Literal[327680]
    """
    specifies that NO is the default button.
    """
    DEFAULT_BUTTON_IGNORE: Literal[393216]
    """
    specifies that IGNORE is the default button.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.registry
from .x_implementation_registration import XImplementationRegistration as XImplementationRegistration_df8c139a

class ImplementationRegistration(XImplementationRegistration_df8c139a):
    """
    Service Class

    is the implementation of the interface XImplementationRegistration.
    
    This service can be used to install or uninstall components (implementations). Further, it is possible to check if all runtime dependencies (needed services) are available to use a specified component.
    
    Guarantees:

    See Also:
        `API ImplementationRegistration <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1registry_1_1ImplementationRegistration.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from .x_storable import XStorable as XStorable_998f0aa7
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class XStorable2(XStorable_998f0aa7):
    """
    extends XStorable.

    See Also:
        `API XStorable2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XStorable2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XStorable2']

    def storeSelf(self, lArguments: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> None:
        """
        stores the data to the URL from which it was loaded.
        
        Only objects which know their locations can be stored.
        
        This is an extension of the XStorable.store(). This method allows to specify some additional parameters for storing process.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.io.IOException: ``IOException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class XPagePrintable(XInterface_8f010a43):
    """
    Print several pages on one printer page.

    See Also:
        `API XPagePrintable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XPagePrintable.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.text.XPagePrintable']

    def getPagePrintSettings(self) -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        These settings contains:
        """
    def printPages(self, xOptions: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> None:
        """
        prints the pages according to the PagePrintSettings.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def setPagePrintSettings(self, aSettings: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> None:
        """
        adjusts the settings of the page printing.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from .x_terminate_listener import XTerminateListener as XTerminateListener_b760e5a
if typing.TYPE_CHECKING:
    from ..lang.event_object import EventObject as EventObject_a3d70b03

class XTerminateListener2(XTerminateListener_b760e5a):
    """
    extend interface XTerminateListener so a listener will be informed in case termination process was canceled by other reasons.

    See Also:
        `API XTerminateListener2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XTerminateListener2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XTerminateListener2']

    def cancelTermination(self, Event: 'EventObject_a3d70b03') -> None:
        """
        is called when the master environment (e.g., desktop) was canceled in it's terminate request.
        
        Termination can be intercepted by throwing TerminationVetoException. But if a listener was queried for termination .. doesn't throw a veto exception ... it doesn't know if termination will be real next time. Because any other listener can throw those exception too ... and so it can happen that after queryTermination() no notifyTermination() will occur. But these listener don't know if it's allowed to start new processes then. Using this optional(!) interface will make it possible to be informed about canceled termination requests also.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart2.data
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .pivot_table_field_entry import PivotTableFieldEntry as PivotTableFieldEntry_81a11104
    from .x_data_sequence import XDataSequence as XDataSequence_11f00e1f

class XPivotTableDataProvider(XInterface_8f010a43):
    """
    Data provider specific for pivot chart data.
    
    **since**
    
        LibreOffice 5.4

    See Also:
        `API XPivotTableDataProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1data_1_1XPivotTableDataProvider.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.chart2.data.XPivotTableDataProvider']

    def createDataSequenceOfCategories(self) -> 'XDataSequence_11f00e1f':
        """
        creates a single data sequence of categories.
        """
    def createDataSequenceOfLabelsByIndex(self, nIndex: int) -> 'XDataSequence_11f00e1f':
        """
        creates a single data sequence of label(s) for the given data series index.
        """
    def createDataSequenceOfValuesByIndex(self, nIndex: int) -> 'XDataSequence_11f00e1f':
        """
        creates a single data sequence of values for the given data series index.
        """
    def getColumnFields(self) -> 'typing.Tuple[PivotTableFieldEntry_81a11104, ...]':
        """
        names of column fields from the associated pivot table
        """
    def getDataFields(self) -> 'typing.Tuple[PivotTableFieldEntry_81a11104, ...]':
        """
        names of data fields from the associated pivot table
        """
    def getFieldOutputDescription(self, nDimensionIndex: int) -> str:
        """
        field output description: either \"- all -\", \"- multiple -\", or specific value
        """
    def getPageFields(self) -> 'typing.Tuple[PivotTableFieldEntry_81a11104, ...]':
        """
        names of page fields from the associated pivot table
        """
    def getPivotTableName(self) -> str:
        """
        get the associated pivot table name
        """
    def getRowFields(self) -> 'typing.Tuple[PivotTableFieldEntry_81a11104, ...]':
        """
        names of row fields from the associated pivot table
        """
    def hasPivotTable(self) -> bool:
        """
        check if the associated pivot table exists
        """
    def setPivotTableName(self, sPivotTableName: str) -> None:
        """
        set the associated pivot table name
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.text
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API WritingMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text.html#a46d11c2d08142ef2d32761c04d1aaa26>`_
"""

LR_TB: 'uno.Enum'
"""
text within lines is written left-to-right.

lines and blocks are placed top-to-bottom.

Typically, this is the writing mode for normal \"alphabetic\" text.
"""
RL_TB: 'uno.Enum'
"""
text within a line are written right-to-left.

Lines and blocks are placed top-to-bottom.

Typically, this writing mode is used in Arabic and Hebrew text.
"""
TB_RL: 'uno.Enum'
"""
text within a line is written top-to-bottom.

Lines and blocks are placed right-to-left.

Typically, this writing mode is used in Chinese and Japanese text.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .enhanced_custom_shape_parameter import EnhancedCustomShapeParameter as EnhancedCustomShapeParameter_d6171317
    from .enhanced_custom_shape_parameter_pair import EnhancedCustomShapeParameterPair as EnhancedCustomShapeParameterPair_262914a3

class EnhancedCustomShapeHandle(ABC):
    """
    Service Class

    This service may be represented by a com.sun.star.beans.PropertyValue [].

    See Also:
        `API EnhancedCustomShapeHandle <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeHandle.html>`_
    """
    @property
    def MirroredX(self) -> bool:
        """
        Specifies if the x position of the handle is mirrored.
        """
    @property
    def MirroredY(self) -> bool:
        """
        Specifies if the y position of the handle is mirrored.
        """
    @property
    def Polar(self) -> 'EnhancedCustomShapeParameterPair_262914a3':
        """
        If this attribute is set, the handle is a polar handle.
        
        The property specifies the center position of the handle. If this attribute is set, the attributes RangeX and RangeY are ignored, instead the attribute RadiusRange is used.
        """
    @property
    def Position(self) -> 'EnhancedCustomShapeParameterPair_262914a3':
        """
        If the property Polar is set, then the first value specifies the radius and the second parameter the angle of the handle.
        
        Otherwise, if the handle is not polar, the first parameter specifies the horizontal handle position, the vertical handle position is described by the second parameter.
        """
    @property
    def RadiusRangeMaximum(self) -> 'EnhancedCustomShapeParameter_d6171317':
        """
        If this attribute is set, it specifies the maximum radius range that can be used for a polar handle.
        """
    @property
    def RadiusRangeMinimum(self) -> 'EnhancedCustomShapeParameter_d6171317':
        """
        If this attribute is set, it specifies the minimum radius range that can be used for a polar handle.
        """
    @property
    def RangeXMaximum(self) -> 'EnhancedCustomShapeParameter_d6171317':
        """
        If the attribute RangeXMaximum is set, it specifies the horizontal maximum range of the handle.
        """
    @property
    def RangeXMinimum(self) -> 'EnhancedCustomShapeParameter_d6171317':
        """
        If the attribute RangeXMinimum is set, it specifies the horizontal minimum range of the handle.
        """
    @property
    def RangeYMaximum(self) -> 'EnhancedCustomShapeParameter_d6171317':
        """
        If the attribute RangeYMaximum is set, it specifies the vertical maximum range of the handle.
        """
    @property
    def RangeYMinimum(self) -> 'EnhancedCustomShapeParameter_d6171317':
        """
        If the attribute RangeYMinimum is set, it specifies the vertical minimum range of the handle.
        """
    @property
    def RefAngle(self) -> int:
        """
        RefAngle, if this attribute is set, it specifies the index of the adjustment value which is connected to the angle of the handle.
        """
    @property
    def RefR(self) -> int:
        """
        RefR, if this attribute is set, it specifies the index of the adjustment value which is connected to the radius of the handle.
        """
    @property
    def RefX(self) -> int:
        """
        RefX, if this attribute is set, it specifies the index of the adjustment value which is connected to the horizontal position of the handle.
        """
    @property
    def RefY(self) -> int:
        """
        RefY, if this attribute is set, it specifies the index of the adjustment value which is connected to the vertical position of the handle.
        """
    @property
    def Switched(self) -> bool:
        """
        Specifies if the handle directions are swapped if the shape is taller than wide.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form.component
import typing
from ..x_database_parameter_broadcaster import XDatabaseParameterBroadcaster as XDatabaseParameterBroadcaster_ac7f1234
from ..x_loadable import XLoadable as XLoadable_8e680a28
from ..x_reset import XReset as XReset_71670917
from .form import Form as Form_ca1d0c51
from ...sdb.row_set import RowSet as RowSet_67d208a5
if typing.TYPE_CHECKING:
    from ..navigation_bar_mode import NavigationBarMode as NavigationBarMode_efbc0d66
    from ..tabulator_cycle import TabulatorCycle as TabulatorCycle_c9250c5a

class DataForm(Form_ca1d0c51, RowSet_67d208a5, XDatabaseParameterBroadcaster_ac7f1234, XLoadable_8e680a28, XReset_71670917):
    """
    Service Class

    This service specifies a form which is connected to a database and displays the results of SQL queries.
    
    It provides the possibility of adding new data records, modifying existing ones, or deleting them.
    
    A database form is a special kind of enhanced database row set which provides all information for displaying the data and has more possibilities for configuring the data manipulation.

    See Also:
        `API DataForm <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DataForm.html>`_
    """
    @property
    def DetailFields(self) -> 'typing.Tuple[str, ...]':
        """
        is used for subforms and contains the names of the columns of the subform which are related to the master fields of the parent form.
        
        Entries in this sequence can either denote column names in the sub form, or parameter names.
        For instance, you could base the form on the SQL statement SELECT * FROM invoices WHERE cust_ref = :cid, and add cid to the DetailFields property. In this case, the parameter will be filled from the corresponding master field.
        Alternatively, you could simply base your form on the table invoices, and add the column name cust_ref to the DetailFields. In this case, and implicit filter clause WHERE cust_ref = :<new_param_name> will be created, and the artificial parameter will be filled from the corresponding master field.
        If a string in this property denotes both a column name and a parameter name, it is undefined which way it is interpreted, but implementations of the service are required to either decide for the parameter or the column, and proceed as usual.
        
        The columns specified herein typically represent a part of the primary key fields or their aliases of the detail form.
        
        If the form is no sub form (e.g. its parent is not a form itself), this property is not evaluated.
        """
    @property
    def MasterFields(self) -> 'typing.Tuple[str, ...]':
        """
        is used for subforms and contains the names of columns of the parent form.
        
        These columns are typically the foreign key fields of the parent form. The values of these columns are used to identify the data for the subform. Each time the parent form changes its current row, the subform requeries it's data based on the values of the master fields.
        
        If the form is no sub form (e.g. its parent is not a form itself), this property is not evaluated.
        """
    @property
    def AllowDeletes(self) -> bool:
        """
        determines if deletions of records of the form are allowed.
        
        Note that this is a recommendation for user interface components displaying the form. Form implementations may decide to allow for deletions done via the API, even if the property is set to FALSE, but the user interface should respect the property value.
        """
    @property
    def AllowInserts(self) -> bool:
        """
        determines if insertions into the form's row set are allowed.
        
        Note that this is a recommendation for user interface components displaying the form. Form implementations may decide to allow for insertions done via the API, even if the property is set to FALSE, but the user interface should respect the property value.
        """
    @property
    def AllowUpdates(self) -> bool:
        """
        determines if modifications of the current record of the form are allowed.
        
        Note that this is a recommendation for user interface components displaying the form. Form implementations may decide to allow for updates done via the API, even if the property is set to FALSE, but the user interface should respect the property value.
        """
    @property
    def Cycle(self) -> 'TabulatorCycle_c9250c5a':
        """
        returns the kind of tabulator controlling.
        """
    @property
    def NavigationBarMode(self) -> 'NavigationBarMode_efbc0d66':
        """
        determines how a navigation bar for this form should act.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
from .x_interaction_supply_authentication import XInteractionSupplyAuthentication as XInteractionSupplyAuthentication_d8611367

class XInteractionSupplyAuthentication2(XInteractionSupplyAuthentication_d8611367):
    """
    An interaction continuation handing back some authentication data.
    
    This continuation is typically used in conjunction with AuthenticationRequest.
    
    **since**
    
        OOo 3.2

    See Also:
        `API XInteractionSupplyAuthentication2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XInteractionSupplyAuthentication2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ucb.XInteractionSupplyAuthentication2']

    def canUseSystemCredentials(self, Default: bool) -> bool:
        """
        Specifies if \"system credentials\" can be obtained and used by the issuer of the authentication request.

        * ``Default`` is an out direction argument.
        """
    def setUseSystemCredentials(self, UseSystemCredentials: bool) -> None:
        """
        Set a new \"use system credentials\" value to hand back.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rendering
from typing_extensions import Literal
"""
Const

These constants determine some extra ways how the primitive color is combined with the background.

Please refer to the PDF specification for explanations of this constants.

See Also:
    `API BlendMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1BlendMode.html>`_
"""
NORMAL: Literal[0]
MULTIPLY: Literal[1]
SCREEN: Literal[2]
OVERLAY: Literal[3]
DARKEN: Literal[4]
LIGHTEN: Literal[5]
COLOR_DODGE: Literal[6]
COLOR_BURN: Literal[7]
HARD_LIGHT: Literal[8]
SOFT_LIGHT: Literal[9]
DIFFERENCE: Literal[10]
EXCLUSION: Literal[11]
HUE: Literal[12]
SATURATION: Literal[13]
COLOR: Literal[14]
LUMINOSITY: Literal[15]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_modify_listener import XModifyListener as XModifyListener_d5c60ccc

class XModifyBroadcaster(XInterface_8f010a43):
    """
    broadcasts each modification made on the date data of the object which supports this interface.
    
    The modified object must post the modification events immediately after the modification is performed.

    See Also:
        `API XModifyBroadcaster <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XModifyBroadcaster.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.util.XModifyBroadcaster']

    def addModifyListener(self, aListener: 'XModifyListener_d5c60ccc') -> None:
        """
        adds the specified listener to receive events \"modified.\"
        """
    def removeModifyListener(self, aListener: 'XModifyListener_d5c60ccc') -> None:
        """
        removes the specified listener.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.script
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .script_event_descriptor import ScriptEventDescriptor as ScriptEventDescriptor_4cef1033
    from .x_script_listener import XScriptListener as XScriptListener_f20b0db0

class XEventAttacherManager(XInterface_8f010a43):
    """
    registers listeners for specified events.

    See Also:
        `API XEventAttacherManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XEventAttacherManager.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.script.XEventAttacherManager']

    def addScriptListener(self, xListener: 'XScriptListener_f20b0db0') -> None:
        """
        adds an XScriptListener that will be notified when an event takes place.
        
        For that a ScriptEventDescriptor is registered at and attached to an object by an XEventAttacherManager.
        
        It is suggested to allow multiple registration of the same listener, thus for each time a listener is added, it has to be removed.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def attach(self, nIndex: int, xObject: 'XInterface_8f010a43', aHelper: object) -> None:
        """
        attaches all the ScriptEvents which are registered for the given index to the given object.
        
        Exceptions of type com.sun.star.beans.IntrospectionException and com.sun.star.script.CannotCreateAdapterException that can be thrown by methods of XEventAttacher are caught and ignored.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.ServiceNotRegisteredException: ``ServiceNotRegisteredException``
        """
    def detach(self, nIndex: int, xObject: 'XInterface_8f010a43') -> None:
        """
        detaches all the ScriptEvents from the given object which are registered at this object for the given index.
        
        Exceptions of type com.sun.star.beans.IntrospectionException and com.sun.star.script.CannotCreateAdapterException that can be thrown by methods of XEventAttacher are caught and ignored.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getScriptEvents(self, Index: int) -> 'typing.Tuple[ScriptEventDescriptor_4cef1033, ...]':
        """

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def insertEntry(self, nIndex: int) -> None:
        """
        creates an empty entry at the given position.
        
        The index n of all entries with n &gt;= nIndex will be increased by one.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def registerScriptEvent(self, nIndex: int, aScriptEvent: 'ScriptEventDescriptor_4cef1033') -> None:
        """
        registers one event for an object identified by its index.
        
        If any object is attached under this index, then this event is attached automatically.
        
        Exceptions of type com.sun.star.beans.IntrospectionException and com.sun.star.script.CannotCreateAdapterException that can be thrown by methods of XEventAttacher are caught and ignored.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def registerScriptEvents(self, nIndex: int, aScriptEvents: 'typing.Tuple[ScriptEventDescriptor_4cef1033, ...]') -> None:
        """
        registers several events for an object identified by its index.
        
        The result is the same as if the method registerScriptEvent() was called once for each ScriptEventDescriptor in the sequence.
        
        If any object is attached under this index, then this event is attached automatically (see attach())
        
        Exceptions of type com.sun.star.beans.IntrospectionException and com.sun.star.script.CannotCreateAdapterException that can be thrown by methods of XEventAttacher are caught and ignored.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def removeEntry(self, nIndex: int) -> None:
        """
        removes the entry at the given position.
        
        If any events are registered at this index, they will be revoked, too. So if the events at this index have been attached to any object they are detached automatically. (see attach()).

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def removeScriptListener(self, Listener: 'XScriptListener_f20b0db0') -> None:
        """
        removes a XScriptListener from the listener list.
        
        Nothing happens if the listener is not registered.
        
        It is suggested to allow multiple registration of the same listener, thus for each time a listener is added, it has to be removed.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def revokeScriptEvent(self, nIndex: int, aListenerType: str, aEventMethod: str, aRemoveListenerParam: str) -> None:
        """
        revokes the registration of an event.
        
        The parameters ListenerType and EventMethod are equivalent to the first two members of the ScriptEventDescriptor used to register events. If this event at this index has been attached to any object, it is detached automatically (see attach()).
        
        Exceptions of type com.sun.star.beans.IntrospectionException and com.sun.star.script.CannotCreateAdapterException that can be thrown by methods of XEventAttacher are caught and ignored.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def revokeScriptEvents(self, nIndex: int) -> None:
        """
        revokes all events which are registered for the given index.
        
        If the events at this index have been attached to any object, they are detached automatically. (see attach()).

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.datatransfer
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class DataFlavor(object):
    """
    Struct Class

    Each instance represents the concept of a data format as it would appear on a clipboard, or during drag and drop.

    See Also:
        `API DataFlavor <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1datatransfer_1_1DataFlavor.html>`_
    """
    typeName: Literal['com.sun.star.datatransfer.DataFlavor']

    def __init__(self, MimeType: typing.Optional[str] = ..., HumanPresentableName: typing.Optional[str] = ..., DataType: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            MimeType (str, optional): MimeType value.
            HumanPresentableName (str, optional): HumanPresentableName value.
            DataType (object, optional): DataType value.
        """


    @property
    def MimeType(self) -> str:
        """
        The MIME content-type (type/subtype) string describing the data format of the object to transfer.
        
        MimeType must conform to Rfc2045 and Rfc2046)
        """


    @property
    def HumanPresentableName(self) -> str:
        """
        A human presentable name for the data format.
        """


    @property
    def DataType(self) -> object:
        """
        The type of the object to transfer, for example, XOutputStream.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal


class Key(object):
    """
    Const

    These values are used to specify distinct physical keys, plus some special values used by the macOS implementation.
    
    **since**
    
        LibreOffice 4.3

    See Also:
        `API Key <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1Key.html>`_
    """
    NUM0: Literal[256]
    NUM1: Literal[257]
    NUM2: Literal[258]
    NUM3: Literal[259]
    NUM4: Literal[260]
    NUM5: Literal[261]
    NUM6: Literal[262]
    NUM7: Literal[263]
    NUM8: Literal[264]
    NUM9: Literal[265]
    A: Literal[512]
    B: Literal[513]
    C: Literal[514]
    D: Literal[515]
    E: Literal[516]
    F: Literal[517]
    G: Literal[518]
    H: Literal[519]
    I: Literal[520]
    J: Literal[521]
    K: Literal[522]
    L: Literal[523]
    M: Literal[524]
    N: Literal[525]
    O: Literal[526]
    P: Literal[527]
    Q: Literal[528]
    R: Literal[529]
    S: Literal[530]
    T: Literal[531]
    U: Literal[532]
    V: Literal[533]
    W: Literal[534]
    X: Literal[535]
    Y: Literal[536]
    Z: Literal[537]
    F1: Literal[768]
    F2: Literal[769]
    F3: Literal[770]
    F4: Literal[771]
    F5: Literal[772]
    F6: Literal[773]
    F7: Literal[774]
    F8: Literal[775]
    F9: Literal[776]
    F10: Literal[777]
    F11: Literal[778]
    F12: Literal[779]
    F13: Literal[780]
    F14: Literal[781]
    F15: Literal[782]
    F16: Literal[783]
    F17: Literal[784]
    F18: Literal[785]
    F19: Literal[786]
    F20: Literal[787]
    F21: Literal[788]
    F22: Literal[789]
    F23: Literal[790]
    F24: Literal[791]
    F25: Literal[792]
    F26: Literal[793]
    DOWN: Literal[1024]
    UP: Literal[1025]
    LEFT: Literal[1026]
    RIGHT: Literal[1027]
    HOME: Literal[1028]
    END: Literal[1029]
    PAGEUP: Literal[1030]
    PAGEDOWN: Literal[1031]
    RETURN: Literal[1280]
    ESCAPE: Literal[1281]
    TAB: Literal[1282]
    BACKSPACE: Literal[1283]
    SPACE: Literal[1284]
    INSERT: Literal[1285]
    DELETE: Literal[1286]
    ADD: Literal[1287]
    SUBTRACT: Literal[1288]
    MULTIPLY: Literal[1289]
    DIVIDE: Literal[1290]
    POINT: Literal[1291]
    COMMA: Literal[1292]
    LESS: Literal[1293]
    GREATER: Literal[1294]
    EQUAL: Literal[1295]
    OPEN: Literal[1296]
    CUT: Literal[1297]
    COPY: Literal[1298]
    PASTE: Literal[1299]
    UNDO: Literal[1300]
    REPEAT: Literal[1301]
    FIND: Literal[1302]
    PROPERTIES: Literal[1303]
    FRONT: Literal[1304]
    CONTEXTMENU: Literal[1305]
    HELP: Literal[1306]
    MENU: Literal[1307]
    HANGUL_HANJA: Literal[1308]
    DECIMAL: Literal[1309]
    TILDE: Literal[1310]
    QUOTELEFT: Literal[1311]
    CAPSLOCK: Literal[1312]
    NUMLOCK: Literal[1313]
    SCROLLLOCK: Literal[1314]
    DELETE_TO_BEGIN_OF_LINE: Literal[1536]
    DELETE_TO_END_OF_LINE: Literal[1537]
    DELETE_TO_BEGIN_OF_PARAGRAPH: Literal[1538]
    BRACKETLEFT: Literal[1315]
    BRACKETRIGHT: Literal[1316]
    SEMICOLON: Literal[1317]
    QUOTERIGHT: Literal[1318]
    DELETE_TO_END_OF_PARAGRAPH: Literal[1539]
    """
    The following values don't correspond to physical keys on any keyboard but are used in the macOS implementation of VCL.
    
    They correspond to some of the action messages of the NSResponder abstract class.
    """
    DELETE_WORD_BACKWARD: Literal[1540]
    DELETE_WORD_FORWARD: Literal[1541]
    INSERT_LINEBREAK: Literal[1542]
    INSERT_PARAGRAPH: Literal[1543]
    MOVE_WORD_BACKWARD: Literal[1544]
    MOVE_WORD_FORWARD: Literal[1545]
    MOVE_TO_BEGIN_OF_LINE: Literal[1546]
    MOVE_TO_END_OF_LINE: Literal[1547]
    MOVE_TO_BEGIN_OF_PARAGRAPH: Literal[1548]
    MOVE_TO_END_OF_PARAGRAPH: Literal[1549]
    SELECT_BACKWARD: Literal[1550]
    SELECT_FORWARD: Literal[1551]
    SELECT_WORD_BACKWARD: Literal[1552]
    SELECT_WORD_FORWARD: Literal[1553]
    SELECT_WORD: Literal[1554]
    SELECT_LINE: Literal[1555]
    SELECT_PARAGRAPH: Literal[1556]
    SELECT_ALL: Literal[1557]
    SELECT_TO_BEGIN_OF_LINE: Literal[1558]
    SELECT_TO_END_OF_LINE: Literal[1559]
    MOVE_TO_BEGIN_OF_DOCUMENT: Literal[1560]
    MOVE_TO_END_OF_DOCUMENT: Literal[1561]
    SELECT_TO_BEGIN_OF_DOCUMENT: Literal[1562]
    SELECT_TO_END_OF_DOCUMENT: Literal[1563]
    SELECT_TO_BEGIN_OF_PARAGRAPH: Literal[1564]
    SELECT_TO_END_OF_PARAGRAPH: Literal[1565]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from typing_extensions import Literal


class FetchError(object):
    """
    Const

    These values are used to specify whether and which error has occurred while fetching data of some ContentResultSet rows.

    See Also:
        `API FetchError <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb_1_1FetchError.html>`_
    """
    SUCCESS: Literal[0]
    """
    indicates that fetching of data was successful.
    """
    ENDOFDATA: Literal[1]
    """
    indicates that during fetching we went beyond the last or first row.
    
    Therefore the FetchResult does not contain the full count of demanded rows, but the maximum possible count must be contained.
    """
    EXCEPTION: Literal[2]
    """
    indicates that during fetching we got an exception.
    
    The row, that causes the exception, and all following ( \"following\" in read order! ) rows are not contained in the FetchResult. Therefore the FetchResult does not contain the full count of demanded rows. But all properly read rows so far must be contained.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.task
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .password_request import PasswordRequest as PasswordRequest_d7280cf7
from ..uno.x_interface import XInterface as XInterface_8f010a43
from .interaction_classification import InteractionClassification as InteractionClassification_6c4d10e7
from .password_request_mode import PasswordRequestMode as PasswordRequestMode_ec10e7c

class DocumentMSPasswordRequest(PasswordRequest_d7280cf7):
    """
    Exception Class

    this request specifies the mode in which the password for Microsoft Office file format encryption should be asked
    
    It is supported by InteractionHandler service, and can be used to interact for a document password. Continuations for using with the mentioned service are Abort and Approve.
    
    **since**
    
        OOo 3.2

    See Also:
        `API DocumentMSPasswordRequest <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1task_1_1DocumentMSPasswordRequest.html>`_
    """

    typeName: Literal['com.sun.star.task.DocumentMSPasswordRequest']

    def __init__(self, Message: typing.Optional[str] = ..., Context: typing.Optional[XInterface_8f010a43] = ..., Classification: typing.Optional[InteractionClassification_6c4d10e7] = ..., Mode: typing.Optional[PasswordRequestMode_ec10e7c] = ..., Name: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            Classification (InteractionClassification, optional): Classification value.
            Mode (PasswordRequestMode, optional): Mode value.
            Name (str, optional): Name value.
        """
    @property
    def Name(self) -> str:
        """
        the name of the document (more properly, the URL of the document)
        """


__all__ = ['DocumentMSPasswordRequest']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing.framework
from typing_extensions import Literal
from abc import ABC

class XModuleController(ABC):
    """
    The module controller is responsible for loading a module (ad-don, plugin, whatever the name) when it is first used.
    
    For this there is a list in the office configuration which associates resource URLs with service names which in turn are associated with modules (or dlls). The path to the office configuration list is MultiPaneGUI/Framework/ResourceFactories in the Impress.xcu file.

    See Also:
        `API XModuleController <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XModuleController.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.drawing.framework.XModuleController']

    def requestResource(self, sResourceTypeURL: str) -> None:
        """
        When the specified resource is requested for the first time then create a new instance of the associated factory service.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from .x_graphics import XGraphics as XGraphics_842309dd
if typing.TYPE_CHECKING:
    from .rectangle import Rectangle as Rectangle_84b109e9
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc

class XGraphics2(XGraphics_842309dd):
    """
    provides the basic output operation of a device.
    
    **since**
    
        LibreOffice 4.1

    See Also:
        `API XGraphics2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XGraphics2']

    def clear(self, aRect: 'Rectangle_84b109e9') -> None:
        """
        clears the given rectangle on the device
        
        **since**
        
            LibreOffice 4.1
        """
    def drawImage(self, nX: int, nY: int, nWidth: int, nHeight: int, nStyle: int, aGraphic: 'XGraphic_a4da0afc') -> None:
        """
        draws a com.sun.star.graphic.XGraphic in the output device.
        
        Note that some devices may not support this operation.
        
        **since**
        
            LibreOffice 4.1
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.document
import typing
from .xxml_basic_exporter import XXMLBasicExporter as XXMLBasicExporter_26ee0eeb
if typing.TYPE_CHECKING:
    from ..xml.sax.x_document_handler import XDocumentHandler as XDocumentHandler_9b90e28

class XMLBasicExporter(XXMLBasicExporter_26ee0eeb):
    """
    Service Class

    Filter for exporting Basic macros to the OpenOffice.org file format.
    
    First the XExporter.setSourceDocument() method must be called in order to provide the export component with the source document from which the data should be exported. After that, the export is started by calling the XFilter.filter() method.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XMLBasicExporter <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1document_1_1XMLBasicExporter.html>`_
    """
    def createWithHandler(self, DocumentHandler: 'XDocumentHandler_9b90e28') -> None:
        """
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.datatransfer.dnd
# Libre Office Version: 7.3
from typing_extensions import Literal
from .drop_target_event import DropTargetEvent as DropTargetEvent_8d651169
from ...uno.x_interface import XInterface as XInterface_8f010a43
import typing
from ..x_transferable import XTransferable as XTransferable_2d800f38
from .x_drop_target_drop_context import XDropTargetDropContext as XDropTargetDropContext_10e81439


class DropTargetDropEvent(DropTargetEvent_8d651169):
    """
    Struct Class

    The DropTargetDropEvent is delivered from the drop target to its currently registered drop target listener.
    
    It contains sufficient information for the originator of the operation to provide appropriate feedback to the end user when the operation completes.

    See Also:
        `API DropTargetDropEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1DropTargetDropEvent.html>`_
    """
    typeName: Literal['com.sun.star.datatransfer.dnd.DropTargetDropEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., Dummy: typing.Optional[int] = ..., Context: typing.Optional[XDropTargetDropContext_10e81439] = ..., DropAction: typing.Optional[int] = ..., LocationX: typing.Optional[int] = ..., LocationY: typing.Optional[int] = ..., SourceActions: typing.Optional[int] = ..., Transferable: typing.Optional[XTransferable_2d800f38] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Dummy (int, optional): Dummy value.
            Context (XDropTargetDropContext, optional): Context value.
            DropAction (int, optional): DropAction value.
            LocationX (int, optional): LocationX value.
            LocationY (int, optional): LocationY value.
            SourceActions (int, optional): SourceActions value.
            Transferable (XTransferable, optional): Transferable value.
        """


    @property
    def Context(self) -> XDropTargetDropContext_10e81439:
        """
        The drop target context of the current drag operation.
        """


    @property
    def DropAction(self) -> int:
        """
        This value represents the action or actions selected by the user at the time of the drop.
        
        If more than one action is specified, the XDropTargetListener should raise a dialog to ask the user which action to use.
        """


    @property
    def LocationX(self) -> int:
        """
        The cursor's current x location within the window's coordinates.
        """


    @property
    def LocationY(self) -> int:
        """
        The cursor's current y location within the window's coordinates.
        """


    @property
    def SourceActions(self) -> int:
        """
        This value represents the action or actions supported by the source.
        """


    @property
    def Transferable(self) -> XTransferable_2d800f38:
        """
        The transferable object associated with the drop.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing
import typing
from .connector_properties import ConnectorProperties as ConnectorProperties_3c5e0fcc
from .line_properties import LineProperties as LineProperties_f13f0da9
from .rotation_descriptor import RotationDescriptor as RotationDescriptor_2cec0f63
from .shadow_properties import ShadowProperties as ShadowProperties_e350e87
from .shape import Shape as Shape_85cc09e5
from .text import Text as Text_7c140999
if typing.TYPE_CHECKING:
    from ..awt.point import Point as Point_5fb2085e
    from .x_shape import XShape as XShape_8fd00a3d

class ConnectorShape(ConnectorProperties_3c5e0fcc, LineProperties_f13f0da9, RotationDescriptor_2cec0f63, ShadowProperties_e350e87, Shape_85cc09e5, Text_7c140999):
    """
    Service Class

    This service is for a ConnectorShape, a specialized Shape, which can be connected to other Shapes or GluePoints.

    See Also:
        `API ConnectorShape <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1ConnectorShape.html>`_
    """
    @property
    def EdgeLine1Delta(self) -> int:
        """
        This property contains the distance of line 1.
        """
    @property
    def EdgeLine2Delta(self) -> int:
        """
        This property contains the distance of line 2.
        """
    @property
    def EdgeLine3Delta(self) -> int:
        """
        This property contains the distance of line 3.
        """
    @property
    def EndGluePointIndex(self) -> int:
        """
        this is the position of the connectors end point in 100th/mm.
        
        For unconnected end points you can get and set the position. For connected end points you can only get the position.
        """
    @property
    def EndPosition(self) -> 'Point_5fb2085e':
        """
        this property holds the index of the gluepoint the end point of this connector is glued on.
        """
    @property
    def EndShape(self) -> 'XShape_8fd00a3d':
        """
        this property either holds the shape that the end point of this connector is connected to, or is empty when the end point of the connector is not connected to a shape.
        """
    @property
    def StartGluePointIndex(self) -> int:
        """
        this property holds the index of the gluepoint the start point of this connector is glued on.
        """
    @property
    def StartPosition(self) -> 'Point_5fb2085e':
        """
        this is the position of the connectors start point in 100th/mm.
        
        For unconnected start points you can get and set the position. For connected start points you can only get the position.
        """
    @property
    def StartShape(self) -> 'XShape_8fd00a3d':
        """
        this property either holds the shape that the start point of this connector is connected to, or is empty when the start point of the connector is not connected to a shape.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.configuration.backend
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ...uno.exception import Exception as Exception_85530a09
from ...uno.x_interface import XInterface as XInterface_8f010a43

class MergeRecoveryRequest(Exception_85530a09):
    """
    Exception Class

    is passed to an InteractionHandler when merging fails due to invalid layer data or access problems.
    
    **since**
    
        OOo 2.0

    See Also:
        `API MergeRecoveryRequest <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1configuration_1_1backend_1_1MergeRecoveryRequest.html>`_
    """

    typeName: Literal['com.sun.star.configuration.backend.MergeRecoveryRequest']

    def __init__(self, Message: typing.Optional[str] = ..., Context: typing.Optional[XInterface_8f010a43] = ..., ErrorDetails: typing.Optional[object] = ..., ErrorLayerId: typing.Optional[str] = ..., IsRemovalRequest: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            ErrorDetails (object, optional): ErrorDetails value.
            ErrorLayerId (str, optional): ErrorLayerId value.
            IsRemovalRequest (bool, optional): IsRemovalRequest value.
        """
    @property
    def ErrorDetails(self) -> object:
        """
        data that provides more detailed information about the reason and location of the error.
        
        Typically this member should contain an exception characterizing the error in detail.
        
        For example the following exceptions may be used:
        
        If no more detail information is available, this may be left VOID.
        """

    @property
    def ErrorLayerId(self) -> str:
        """
        Identifier of the layer object containing the invalid data.
        """

    @property
    def IsRemovalRequest(self) -> bool:
        """
        specifies whether the requester wants to remove or skip the invalid layer.
        
        If TRUE the requester wants to remove the underlying data of the layer.
        If FALSE the request is to skip the underlying data this time, but without removing it.
        """


__all__ = ['MergeRecoveryRequest']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form.runtime
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ...awt.x_control import XControl as XControl_7a9c098d

class XFormControllerContext(ABC):
    """
    provides a context for a FormController
    
    A FormController knows about the controls it is responsible for, and about the control container which those controls live in. However, it doesn't know about a possible larger context, like a scrollable view which the controls are embedded into. To compensate this, it can be provided a XFormControllerContext.

    See Also:
        `API XFormControllerContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1runtime_1_1XFormControllerContext.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.form.runtime.XFormControllerContext']

    def makeVisible(self, Control: 'XControl_7a9c098d') -> None:
        """
        ensures the given control is visible, by scrolling the view if necessary.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form
from typing_extensions import Literal
"""
Const

These constants specify the class types used to identify a component.

See Also:
    `API FormComponentType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1form_1_1FormComponentType.html>`_
"""
CONTROL: Literal[1]
"""
This generic identifier is for controls which cannot be identified by another specific identifier.
"""
COMMANDBUTTON: Literal[2]
"""
specifies a control that is used to begin, interrupt, or end a process.
"""
RADIOBUTTON: Literal[3]
"""
specifies a control that acts like a radio button.

Grouped together, such radio buttons present a set of two or more mutually exclusive choices to the user.
"""
IMAGEBUTTON: Literal[4]
"""
specifies a control that displays an image that responds to mouse clicks.
"""
CHECKBOX: Literal[5]
"""
specifies a control that is used to check or uncheck to turn an option on or off.
"""
LISTBOX: Literal[6]
"""
specifies a control that displays a list from which the user can select one or more items.
"""
COMBOBOX: Literal[7]
"""
specifies a control that is used when a list box combined with a static text control or an edit control is needed.
"""
GROUPBOX: Literal[8]
"""
specifies a control that displays a frame around a group of controls with or without a caption.
"""
TEXTFIELD: Literal[9]
"""
specifies a control that is a text component that allows for the editing of a single line of text.
"""
FIXEDTEXT: Literal[10]
"""
specifies a control to display a fixed text, usually used to label other controls.
"""
GRIDCONTROL: Literal[11]
"""
is a table like control to display database data.
"""
FILECONTROL: Literal[12]
"""
specifies a control which can be used to enter text, extended by an (user-startable) file dialog to browse for files.
"""
HIDDENCONTROL: Literal[13]
"""
specifies a control that should not be visible.
"""
IMAGECONTROL: Literal[14]
"""
specifies a control to display an image.
"""
DATEFIELD: Literal[15]
"""
specifies a control to display and edit a date value.
"""
TIMEFIELD: Literal[16]
"""
specifies a control to display and edit a time value.
"""
NUMERICFIELD: Literal[17]
"""
specifies a field to display and edit a numeric value.
"""
CURRENCYFIELD: Literal[18]
"""
specifies a field to display and edit a currency value.
"""
PATTERNFIELD: Literal[19]
"""
specifies a control to display and edit a string according to a pattern.
"""
SCROLLBAR: Literal[20]
"""
specifies a control to display and edit, in the form of a scrollbar, a value from a continuous value range
"""
SPINBUTTON: Literal[21]
"""
specifies a control to edit, in the form of a spin field, a value from a continuous range of values
"""
NAVIGATIONBAR: Literal[22]
"""
specifies a control which provides controller functionality for the com.sun.star.form.component.DataForm it belongs to, such as functionality to navigate or filter this form.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.geometry
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class RealRectangle3D(object):
    """
    Struct Class

    This structure contains the necessary information for a three-dimensional cube.
    
    **since**
    
        OOo 2.0

    See Also:
        `API RealRectangle3D <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1geometry_1_1RealRectangle3D.html>`_
    """
    typeName: Literal['com.sun.star.geometry.RealRectangle3D']

    def __init__(self, X1: typing.Optional[float] = ..., Y1: typing.Optional[float] = ..., Z1: typing.Optional[float] = ..., X2: typing.Optional[float] = ..., Y2: typing.Optional[float] = ..., Z2: typing.Optional[float] = ...) -> None:
        """
        Constructor

        Arguments:
            X1 (float, optional): X1 value.
            Y1 (float, optional): Y1 value.
            Z1 (float, optional): Z1 value.
            X2 (float, optional): X2 value.
            Y2 (float, optional): Y2 value.
            Z2 (float, optional): Z2 value.
        """


    @property
    def X1(self) -> float:
        """
        minimum X coordinate.
        """


    @property
    def Y1(self) -> float:
        """
        minimum Y coordinate.
        """


    @property
    def Z1(self) -> float:
        """
        minimum Z coordinate.
        """


    @property
    def X2(self) -> float:
        """
        maximum X coordinate.
        
        Must be greater than X1 for non-empty cubes.
        
        .
        """


    @property
    def Y2(self) -> float:
        """
        maximum Y coordinate.
        
        Must be greater than Y1 for non-empty cubes.
        """


    @property
    def Z2(self) -> float:
        """
        maximum Z coordinate.
        
        Must be greater than Z1 for non-empty cubes.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .date import Date as Date_60040844


class DateWithTimezone(object):
    """
    Struct Class

    represents a date value with time zone.
    
    **since**
    
        LibreOffice 4.1

    See Also:
        `API DateWithTimezone <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1DateWithTimezone.html>`_
    """
    typeName: Literal['com.sun.star.util.DateWithTimezone']

    def __init__(self, DateInTZ: typing.Optional[Date_60040844] = ..., Timezone: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            DateInTZ (Date, optional): DateInTZ value.
            Timezone (int, optional): Timezone value.
        """


    @property
    def DateInTZ(self) -> Date_60040844:
        """
        the date.
        """


    @property
    def Timezone(self) -> int:
        """
        contains the time zone, as signed offset in minutes from UTC, that is east of UTC, that is the amount of minutes that should be added to UTC time to obtain time in that timezone.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ..._pyi.form.inspection.button_navigation_handler import ButtonNavigationHandler as ButtonNavigationHandler
from ..._pyi.form.inspection.cell_binding_property_handler import CellBindingPropertyHandler as CellBindingPropertyHandler
from ..._pyi.form.inspection.default_form_component_inspector_model import DefaultFormComponentInspectorModel as DefaultFormComponentInspectorModel
from ..._pyi.form.inspection.edit_property_handler import EditPropertyHandler as EditPropertyHandler
from ..._pyi.form.inspection.event_handler import EventHandler as EventHandler
from ..._pyi.form.inspection.form_component_property_handler import FormComponentPropertyHandler as FormComponentPropertyHandler
from ..._pyi.form.inspection.submission_property_handler import SubmissionPropertyHandler as SubmissionPropertyHandler
from ..._pyi.form.inspection.xml_forms_property_handler import XMLFormsPropertyHandler as XMLFormsPropertyHandler
from ..._pyi.form.inspection.xsd_validation_property_handler import XSDValidationPropertyHandler as XSDValidationPropertyHandler



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XTimeStamped(XInterface_8f010a43):
    """
    provides timestamp information for an object in the form of an arbitrary string.
    
    The format and meaning of the timestamp depends on the implementation. Services implementing this interface must document the meaning and format they use.
    
    If the timestamp is unchanged between two calls, the associated object has not changed. Any properties beyond this, particularly the presence of a meaningful order between timestamps, depend on the implementation.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XTimeStamped <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XTimeStamped.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.util.XTimeStamped']

    def getTimestamp(self) -> str:
        """
        returns the timestamp of the object.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rdf
from typing_extensions import Literal
"""
Const

Constants to specify some well-known URIs.

These constants are for use with URI.createKnown().

**since**

    OOo 3.2

See Also:
    `API URIs <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rdf_1_1URIs.html>`_
"""
XSD_NCNAME: Literal[1]
"""
http://www.w3.org/2001/XMLSchema-datatypes#NCName
"""
XSD_STRING: Literal[2]
"""
http://www.w3.org/2001/XMLSchema-datatypes#string
"""
XSD_NORMALIZEDSTRING: Literal[3]
"""
http://www.w3.org/2001/XMLSchema-datatypes#normalizedString
"""
XSD_BOOLEAN: Literal[4]
"""
http://www.w3.org/2001/XMLSchema-datatypes#boolean
"""
XSD_DECIMAL: Literal[5]
"""
http://www.w3.org/2001/XMLSchema-datatypes#decimal
"""
XSD_FLOAT: Literal[6]
"""
http://www.w3.org/2001/XMLSchema-datatypes#float
"""
XSD_DOUBLE: Literal[7]
"""
http://www.w3.org/2001/XMLSchema-datatypes#double
"""
XSD_INTEGER: Literal[8]
"""
http://www.w3.org/2001/XMLSchema-datatypes#integer
"""
XSD_NONNEGATIVEINTEGER: Literal[9]
"""
http://www.w3.org/2001/XMLSchema-datatypes#nonNegativeInteger
"""
XSD_POSITIVEINTEGER: Literal[10]
"""
http://www.w3.org/2001/XMLSchema-datatypes#positiveInteger
"""
XSD_NONPOSITIVEINTEGER: Literal[11]
"""
http://www.w3.org/2001/XMLSchema-datatypes#nonPositiveInteger
"""
XSD_NEGATIVEINTEGER: Literal[12]
"""
http://www.w3.org/2001/XMLSchema-datatypes#negativeInteger
"""
XSD_LONG: Literal[13]
"""
http://www.w3.org/2001/XMLSchema-datatypes#long
"""
XSD_INT: Literal[14]
"""
http://www.w3.org/2001/XMLSchema-datatypes#int
"""
XSD_SHORT: Literal[15]
"""
http://www.w3.org/2001/XMLSchema-datatypes#short
"""
XSD_BYTE: Literal[16]
"""
http://www.w3.org/2001/XMLSchema-datatypes#byte
"""
XSD_UNSIGNEDLONG: Literal[17]
"""
http://www.w3.org/2001/XMLSchema-datatypes#unsignedLong
"""
XSD_UNSIGNEDINT: Literal[18]
"""
http://www.w3.org/2001/XMLSchema-datatypes#unsignedInt
"""
XSD_UNSIGNEDSHORT: Literal[19]
"""
http://www.w3.org/2001/XMLSchema-datatypes#unsignedShort
"""
XSD_UNSIGNEDBYTE: Literal[20]
"""
http://www.w3.org/2001/XMLSchema-datatypes#unsignedByte
"""
XSD_HEXBINARY: Literal[21]
"""
http://www.w3.org/2001/XMLSchema-datatypes#hexBinary
"""
XSD_BASE64BINARY: Literal[22]
"""
http://www.w3.org/2001/XMLSchema-datatypes#base64Binary
"""
XSD_DATETIME: Literal[23]
"""
http://www.w3.org/2001/XMLSchema-datatypes#dateTime
"""
XSD_TIME: Literal[24]
"""
http://www.w3.org/2001/XMLSchema-datatypes#time
"""
XSD_DATE: Literal[25]
"""
http://www.w3.org/2001/XMLSchema-datatypes#date
"""
XSD_GYEARMONTH: Literal[26]
"""
http://www.w3.org/2001/XMLSchema-datatypes#gYearMonth
"""
XSD_GYEAR: Literal[27]
"""
http://www.w3.org/2001/XMLSchema-datatypes#gYear
"""
XSD_GMONTHDAY: Literal[28]
"""
http://www.w3.org/2001/XMLSchema-datatypes#gMonthDay
"""
XSD_GDAY: Literal[29]
"""
http://www.w3.org/2001/XMLSchema-datatypes#gDay
"""
XSD_GMONTH: Literal[30]
"""
http://www.w3.org/2001/XMLSchema-datatypes#gMonth
"""
XSD_ANYURI: Literal[31]
"""
http://www.w3.org/2001/XMLSchema-datatypes#anyURI
"""
XSD_TOKEN: Literal[32]
"""
http://www.w3.org/2001/XMLSchema-datatypes#token
"""
XSD_LANGUAGE: Literal[33]
"""
http://www.w3.org/2001/XMLSchema-datatypes#language
"""
XSD_NMTOKEN: Literal[34]
"""
http://www.w3.org/2001/XMLSchema-datatypes#NMTOKEN
"""
XSD_NAME: Literal[35]
"""
http://www.w3.org/2001/XMLSchema-datatypes#Name
"""
XSD_DURATION: Literal[36]
"""
http://www.w3.org/2001/XMLSchema-datatypes#duration
"""
XSD_QNAME: Literal[37]
"""
http://www.w3.org/2001/XMLSchema-datatypes#QName
"""
XSD_NOTATION: Literal[38]
"""
http://www.w3.org/2001/XMLSchema-datatypes#NOTATION
"""
XSD_NMTOKENS: Literal[39]
"""
http://www.w3.org/2001/XMLSchema-datatypes#NMTOKENS
"""
XSD_ID: Literal[40]
"""
http://www.w3.org/2001/XMLSchema-datatypes#ID
"""
XSD_IDREF: Literal[41]
"""
http://www.w3.org/2001/XMLSchema-datatypes#IDREF
"""
XSD_IDREFS: Literal[42]
"""
http://www.w3.org/2001/XMLSchema-datatypes#IDREFS
"""
XSD_ENTITY: Literal[43]
"""
http://www.w3.org/2001/XMLSchema-datatypes#ENTITY
"""
XSD_ENTITIES: Literal[44]
"""
http://www.w3.org/2001/XMLSchema-datatypes#ENTITIES
"""
RDF_TYPE: Literal[1000]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#type
"""
RDF_SUBJECT: Literal[1001]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#subject
"""
RDF_PREDICATE: Literal[1002]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#predicate
"""
RDF_OBJECT: Literal[1003]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#object
"""
RDF_PROPERTY: Literal[1004]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#Property
"""
RDF_STATEMENT: Literal[1005]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#Statement
"""
RDF_VALUE: Literal[1006]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#value
"""
RDF_FIRST: Literal[1007]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#first
"""
RDF_REST: Literal[1008]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#rest
"""
RDF_NIL: Literal[1009]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#nil
"""
RDF_XMLLITERAL: Literal[1010]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral
"""
RDF_ALT: Literal[1011]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#Alt
"""
RDF_BAG: Literal[1012]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#Bag
"""
RDF_LIST: Literal[1013]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#List
"""
RDF_SEQ: Literal[1014]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#Seq
"""
RDF_1: Literal[1015]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#_1
"""
RDFS_COMMENT: Literal[1100]
"""
http://www.w3.org/2000/01/rdf-schema#comment
"""
RDFS_LABEL: Literal[1101]
"""
http://www.w3.org/2000/01/rdf-schema#label
"""
RDFS_DOMAIN: Literal[1102]
"""
http://www.w3.org/2000/01/rdf-schema#domain
"""
RDFS_RANGE: Literal[1103]
"""
http://www.w3.org/2000/01/rdf-schema#range
"""
RDFS_SUBCLASSOF: Literal[1104]
"""
http://www.w3.org/2000/01/rdf-schema#subClassOf
"""
RDFS_LITERAL: Literal[1105]
"""
http://www.w3.org/2000/01/rdf-schema#Literal
"""
RDFS_MEMBER: Literal[1106]
"""
http://www.w3.org/2000/01/rdf-schema#member
"""
RDFS_SUBPROPERTYOF: Literal[1107]
"""
http://www.w3.org/2000/01/rdf-schema#subPropertyOf
"""
RDFS_ISDEFINEDBY: Literal[1108]
"""
http://www.w3.org/2000/01/rdf-schema#isDefinedBy
"""
RDFS_SEEALSO: Literal[1109]
"""
http://www.w3.org/2000/01/rdf-schema#seeAlso
"""
RDFS_RESOURCE: Literal[1110]
"""
http://www.w3.org/2000/01/rdf-schema#Resource
"""
RDFS_CLASS: Literal[1111]
"""
http://www.w3.org/2000/01/rdf-schema#Class
"""
RDFS_DATATYPE: Literal[1112]
"""
http://www.w3.org/2000/01/rdf-schema#Datatype
"""
RDFS_CONTAINER: Literal[1113]
"""
http://www.w3.org/2000/01/rdf-schema#Container
"""
RDFS_CONTAINERMEMBERSHIPPROPERTY: Literal[1114]
"""
http://www.w3.org/2000/01/rdf-schema#ContainerMembershipProperty
"""
OWL_CLASS: Literal[1200]
"""
http://www.w3.org/2002/07/owl#Class
"""
OWL_OBJECTPROPERTY: Literal[1201]
"""
http://www.w3.org/2002/07/owl#ObjectProperty
"""
OWL_DATATYPEPROPERTY: Literal[1202]
"""
http://www.w3.org/2002/07/owl#DatatypeProperty
"""
OWL_FUNCTIONALPROPERTY: Literal[1203]
"""
http://www.w3.org/2002/07/owl#FunctionalProperty
"""
OWL_THING: Literal[1204]
"""
http://www.w3.org/2002/07/owl#Thing
"""
OWL_NOTHING: Literal[1205]
"""
http://www.w3.org/2002/07/owl#Nothing
"""
OWL_INDIVIDUAL: Literal[1206]
"""
http://www.w3.org/2002/07/owl#Individual
"""
OWL_EQUIVALENTCLASS: Literal[1207]
"""
http://www.w3.org/2002/07/owl#equivalentClass
"""
OWL_EQUIVALENTPROPERTY: Literal[1208]
"""
http://www.w3.org/2002/07/owl#equivalentProperty
"""
OWL_SAMEAS: Literal[1209]
"""
http://www.w3.org/2002/07/owl#sameAs
"""
OWL_DIFFERENTFROM: Literal[1210]
"""
http://www.w3.org/2002/07/owl#differentFrom
"""
OWL_ALLDIFFERENT: Literal[1211]
"""
http://www.w3.org/2002/07/owl#AllDifferent
"""
OWL_DISTINCTMEMBERS: Literal[1212]
"""
http://www.w3.org/2002/07/owl#distinctMembers
"""
OWL_INVERSEOF: Literal[1213]
"""
http://www.w3.org/2002/07/owl#inverseOf
"""
OWL_TRANSITIVEPROPERTY: Literal[1214]
"""
http://www.w3.org/2002/07/owl#TransitiveProperty
"""
OWL_SYMMETRICPROPERTY: Literal[1215]
"""
http://www.w3.org/2002/07/owl#SymmetricProperty
"""
OWL_INVERSEFUNCTIONALPROPERTY: Literal[1216]
"""
http://www.w3.org/2002/07/owl#InverseFunctionalProperty
"""
OWL_RESTRICTION: Literal[1217]
"""
http://www.w3.org/2002/07/owl#Restriction
"""
OWL_ONPROPERTY: Literal[1218]
"""
http://www.w3.org/2002/07/owl#onProperty
"""
OWL_ALLVALUESFROM: Literal[1219]
"""
http://www.w3.org/2002/07/owl#allValuesFrom
"""
OWL_SOMEVALUESFROM: Literal[1220]
"""
http://www.w3.org/2002/07/owl#someValuesFrom
"""
OWL_MINCARDINALITY: Literal[1221]
"""
http://www.w3.org/2002/07/owl#minCardinality
"""
OWL_MAXCARDINALITY: Literal[1222]
"""
http://www.w3.org/2002/07/owl#maxCardinality
"""
OWL_CARDINALITY: Literal[1223]
"""
http://www.w3.org/2002/07/owl#cardinality
"""
OWL_ONTOLOGY: Literal[1224]
"""
http://www.w3.org/2002/07/owl#Ontology
"""
OWL_IMPORTS: Literal[1225]
"""
http://www.w3.org/2002/07/owl#imports
"""
OWL_VERSIONINFO: Literal[1226]
"""
http://www.w3.org/2002/07/owl#versionInfo
"""
OWL_PRIORVERSION: Literal[1227]
"""
http://www.w3.org/2002/07/owl#priorVersion
"""
OWL_BACKWARDCOMPATIBLEWITH: Literal[1228]
"""
http://www.w3.org/2002/07/owl#backwardCompatibleWith
"""
OWL_INCOMPATIBLEWITH: Literal[1229]
"""
http://www.w3.org/2002/07/owl#incompatibleWith
"""
OWL_DEPRECATEDCLASS: Literal[1230]
"""
http://www.w3.org/2002/07/owl#DeprecatedClass
"""
OWL_DEPRECATEDPROPERTY: Literal[1231]
"""
http://www.w3.org/2002/07/owl#DeprecatedProperty
"""
OWL_ANNOTATIONPROPERTY: Literal[1232]
"""
http://www.w3.org/2002/07/owl#AnnotationProperty
"""
OWL_ONTOLOGYPROPERTY: Literal[1233]
"""
http://www.w3.org/2002/07/owl#OntologyProperty
"""
OWL_ONEOF: Literal[1234]
"""
http://www.w3.org/2002/07/owl#oneOf
"""
OWL_DATARANGE: Literal[1235]
"""
http://www.w3.org/2002/07/owl#dataRange
"""
OWL_DISJOINTWITH: Literal[1236]
"""
http://www.w3.org/2002/07/owl#disjointWith
"""
OWL_UNIONOF: Literal[1237]
"""
http://www.w3.org/2002/07/owl#unionOf
"""
OWL_COMPLEMENTOF: Literal[1238]
"""
http://www.w3.org/2002/07/owl#complementOf
"""
OWL_INTERSECTIONOF: Literal[1239]
"""
http://www.w3.org/2002/07/owl#intersectionOf
"""
OWL_HASVALUE: Literal[1240]
"""
http://www.w3.org/2002/07/owl#hasValue
"""
PKG_HASPART: Literal[2000]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/pkg#hasPart
"""
PKG_MIMETYPE: Literal[2003]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/pkg#mimeType
"""
PKG_PACKAGE: Literal[2004]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/pkg#Package
"""
PKG_ELEMENT: Literal[2005]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/pkg#Element
"""
PKG_FILE: Literal[2006]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/pkg#File
"""
PKG_METADATAFILE: Literal[2007]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/pkg#MetadataFile
"""
PKG_DOCUMENT: Literal[2008]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/pkg#Document
"""
ODF_PREFIX: Literal[2100]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/odf#prefix
"""
ODF_SUFFIX: Literal[2101]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/odf#suffix
"""
ODF_ELEMENT: Literal[2102]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/odf#Element
"""
ODF_CONTENTFILE: Literal[2103]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/odf#ContentFile
"""
ODF_STYLESFILE: Literal[2104]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/odf#StylesFile
"""
LO_EXT_SHADING: Literal[2106]
"""
custom shading color of an annotated text range or metadata field (replacement of the default field shading color)

urn:org:documentfoundation:names:experimental:office:xmlns:loext:1.0odf#shading

**since**

    LibreOffice 7.2
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.embed
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XActionsApproval(XInterface_8f010a43):
    """
    allows to request an approval for an action.
    
    An implementation of this interface is usually provided to another object to allow this object to request an approval for actions. The list of possible actions must be documented in documentation of the object.

    See Also:
        `API XActionsApproval <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XActionsApproval.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.embed.XActionsApproval']

    def approveAction(self, nAction: int) -> bool:
        """
        requests an approval for the specified action.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb
import typing
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_bookmarks_supplier import XBookmarksSupplier as XBookmarksSupplier_ee870d96
from .x_completed_connection import XCompletedConnection as XCompletedConnection_98a0e46
from .x_query_definitions_supplier import XQueryDefinitionsSupplier as XQueryDefinitionsSupplier_5913107f
from ..sdbc.x_data_source import XDataSource as XDataSource_a2990ae7
from ..sdbc.x_isolated_connection import XIsolatedConnection as XIsolatedConnection_99c0e41
from ..util.x_flushable import XFlushable as XFlushable_9a420ab4
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..util.x_number_formats_supplier import XNumberFormatsSupplier as XNumberFormatsSupplier_3afb0fb7

class DataSource(XPropertySet_bc180bfa, XBookmarksSupplier_ee870d96, XCompletedConnection_98a0e46, XQueryDefinitionsSupplier_5913107f, XDataSource_a2990ae7, XIsolatedConnection_99c0e41, XFlushable_9a420ab4):
    """
    Service Class

    is a factory to establish database connections.
    
    It should be registered at a com.sun.star.uno.NamingService.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API DataSource <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DataSource.html>`_
    """
    @property
    def Info(self) -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        is a list of arbitrary string tag/value pairs as connection arguments
        
        The DataSource itself does not attempt to interpret any of those values.
        
        Instead, the values in this property have two use cases:
        """
    @property
    def TableFilter(self) -> 'typing.Tuple[str, ...]':
        """
        defines a list of tables, on which the DataSource should have it's focus.
        
        If empty, all tables are rejected.
        """
    @property
    def TableTypeFilter(self) -> 'typing.Tuple[str, ...]':
        """
        defines a list of table types, on which the DataSource should have it's focus.
        
        If empty, all table types are rejected.
        """
    @property
    def IsPasswordRequired(self) -> bool:
        """
        indicates that a password is always necessary.
        """
    @property
    def IsReadOnly(self) -> bool:
        """
        determines whether modifications on the data source are allowed or not.
        """
    @property
    def Name(self) -> str:
        """
        is the name of the data source.
        
        If the data source is registered at the database context, then the Name property denotes the registration name. Otherwise, the name property contains the URL of the file which the database document associated with the data source is based on.
        
        If the same data source is registered under different names, the value of the Name property is not defined.
        """
    @property
    def NumberFormatsSupplier(self) -> 'XNumberFormatsSupplier_3afb0fb7':
        """
        provides an object for formatting numbers.
        """
    @property
    def Password(self) -> str:
        """
        determines a users password.
        
        The password is not persistent.
        """
    @property
    def Settings(self) -> 'XPropertySet_bc180bfa':
        """
        is a convenience wrapper around the Info property.
        
        Since fiddling around with a sequence of property values is somewhat uncomfortable in all known UNO language bindings (especially for tasks like simply changing the value of an existing value), the Settings property wraps the Info property for easier single-value access.
        
        You should use the Settings property if you need to access a few properties only, and the Info property if you need access to all existent settings at once.
        
        The object represented by this property supports the com.sun.star.beans.PropertyBag service. That is, you can at runtime add arbitrary new properties to the bag.
        
        Additionally, the property bag supports default values of properties, and thus the com.sun.star.beans.XPropertyState interface. If you add an own property to the bag using com.sun.star.beans.XPropertyContainer.addProperty(), you need to specify an initial value, which is also used as default value (exceptions see below).
        
        Effectively, the property bag represented by Settings contains two classes of properties: Pre-defined ones and user-defined ones.
        
        Pre-defined properties are properties which are potentially used by the data source, the application UI for the data source, or a particular backend driver employed by the data source. There's a large set of such properties, no all of them are effectively used for a concrete data source, nonetheless, they're all present in the Settings.
        Such properties are not removable from the bag, that is, their com.sun.star.beans.PropertyAttribute.REMOVABLE attribute is not set.
        Usually, you'll find that all of this properties have the com.sun.star.beans.PropertyState.PropertyState_DEFAULT_VALUE state.
        
        User-defined properties are the ones which are added at runtime by any instance. They might or might not be removable, this depends on whether or not the code adding them specifies the com.sun.star.beans.PropertyAttribute.REMOVABLE attribute. Also, they might or might not have a default value, determined by the com.sun.star.beans.PropertyAttribute.MAYBEDEFAULT attribute at the time they're added to the bag.
        
        When a data source is made persistent, then properties which are not removable (which are assumed to be the pre-defined properties) are ignored when they are in DEFAULT state. All other properties are always made persistent, except when an explicit com.sun.star.beans.PropertyAttribute.TRANSIENT attribute prohibits this.
        
        Similar, when you obtain the Info property of a DataSource, the Settings bag is asked for all its property values, and the ones which are removable and in state default are stripped, and not returned in the Info sequence.
        """
    @property
    def SuppressVersionColumns(self) -> bool:
        """
        indicates that components displaying data obtained from this data source should suppress columns used for versioning.
        """
    @property
    def URL(self) -> str:
        """
        indicates a database url of the form
        jdbc:subprotocol:subname or sdbc:subprotocol:subname
        """
    @property
    def User(self) -> str:
        """
        determines a users login name.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.auth
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XSSOPasswordCache(XInterface_8f010a43):
    """
    supports password caching for security mechanisms which use passwords as credentials or as an input to credential creation but don't have an external method to cache these passwords.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XSSOPasswordCache <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1auth_1_1XSSOPasswordCache.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.auth.XSSOPasswordCache']

    def addPassword(self, UserName: str, Password: str, Persist: bool) -> None:
        """
        adds a username/password combination to the cache.
        
        If an entry for the specified username already exists in the cache, it will be overwritten.

        Raises:
            InvalidArgumentException: ``InvalidArgumentException``
            PersistenceFailureException: ``PersistenceFailureException``
        """
    def getPassword(self, UserName: str, Persist: bool) -> str:
        """
        retrieves a password for a given user from the cache.
        
        Non persistent cache is searched first, followed by the persistent cache ( if it exists ).

        * ``Persist`` is an out direction argument.

        Raises:
            InvalidArgumentException: ``InvalidArgumentException``
            PersistenceFailureException: ``PersistenceFailureException``
        """
    def removePassword(self, UserName: str, RemovePersist: bool) -> None:
        """
        removes a password from the cache

        Raises:
            InvalidArgumentException: ``InvalidArgumentException``
            PersistenceFailureException: ``PersistenceFailureException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..geometry.affine_matrix2_d import AffineMatrix2D as AffineMatrix2D_ff040da8
from .x_poly_polygon2_d import XPolyPolygon2D as XPolyPolygon2D_e1b0e20


class ViewState(object):
    """
    Struct Class

    This structure contains information considered the view state.
    
    This structure contains information considered the view state, i.e. the invariant setup used when painting a whole view of something.
    
    **since**
    
        OOo 2.0

    See Also:
        `API ViewState <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1ViewState.html>`_
    """
    typeName: Literal['com.sun.star.rendering.ViewState']

    def __init__(self, AffineTransform: typing.Optional[AffineMatrix2D_ff040da8] = ..., Clip: typing.Optional[XPolyPolygon2D_e1b0e20] = ...) -> None:
        """
        Constructor

        Arguments:
            AffineTransform (AffineMatrix2D, optional): AffineTransform value.
            Clip (XPolyPolygon2D, optional): Clip value.
        """


    @property
    def AffineTransform(self) -> AffineMatrix2D_ff040da8:
        """
        The affine transform associated with the view.
        
        This member is used to transform coordinates of draw operations from user space to screen space.
        """


    @property
    def Clip(self) -> XPolyPolygon2D_e1b0e20:
        """
        The clipping area associated with the view.
        
        This clipping is interpreted in the view coordinate systems, i.e. subject to the view transform before mapping to the device coordinate space.
        
        Specifying an empty interface denotes no clipping, i.e. everything rendered to the canvas will be visible (subject to device-dependent constraints, of course). Specifying an empty XPolyPolygon2D, i.e. a poly-polygon containing zero polygons, or an XPolyPolygon2D with any number of empty sub-polygons, denotes the NULL clip. That means, nothing rendered to the canvas will be visible.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from typing_extensions import Literal


class SearchFlags(object):
    """
    Const

    Flags for search methods.
    
    **since**
    
        LibreOffice 5.2

    See Also:
        `API SearchFlags <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1util_1_1SearchFlags.html>`_
    """
    ALL_IGNORE_CASE: Literal[1]
    NORM_WORD_ONLY: Literal[16]
    """
    Flag for normal (Boyer-Moore) search / Search for word only.
    """
    REG_EXTENDED: Literal[256]
    """
    Flag for \"regular expression\" search / Interpret as extended regular expression.
    """
    REG_NOSUB: Literal[512]
    """
    Flag for \"regular expression\" search / No register information or backreferences, i.e., avoid sub expressions.
    
    Return only true/false if matched or not.
    """
    REG_NEWLINE: Literal[1024]
    """
    Flag for \"regular expression\" search / Special new line treatment.
    
    A NEWLINE character in string will not be matched by a period outside bracket expression or by any form of a non matching list.
    
    A circumflex (^) in pattern when used to specify expression anchoring will match the zero length string immediately after a newline in string, regardless of the setting of REG_NOT_BEGINOFLINE.
    
    A dollar-sign ($) in pattern when used to specify expression anchoring, will match zero-length string immediately before a new line in string, regardless of the setting of REG_NOT_ENDOFLINE.
    """
    REG_NOT_BEGINOFLINE: Literal[2048]
    """
    The first character in the string is not the beginning of the line therefore ^ will not match with first character of the string.
    """
    REG_NOT_ENDOFLINE: Literal[4096]
    """
    The last character in the string is not the end of the line therefore $ will not match with last character of the string.
    """
    LEV_RELAXED: Literal[65536]
    """
    Flag for \"Weighted Levenshtein Distance\" search / Relaxed checking of limit, split weigh pools.
    
    If not specified (strict), the search is successful if the WLD is within a calculated limit where each insertion, deletion and replacement adds a weight to a common pool of weights. This is the mathematically correct WLD.
    
    From a user's point of view the strict WLD is an exclusive-OR of the arguments given, for example if allowed insertions=2 and allowed replacements=2, the search fails if 2 characters had been inserted and an additional operation would be needed to match. Depending on the weights it may also fail if 1 character was inserted and 1 character replaced and an additional operation would be needed to match. The strict algorithm may match less than expected from a first glance of the specified arguments, but does not return false positives.
    
    If specified (relaxed), the search is also successful if the combined pool for insertions and deletions is below a doubled calculated limit and replacements are treated differently. Additionally, swapped characters are counted as one replacement.
    
    From a user's point of view the relaxed WLD is an inclusive-OR of the arguments given, for example if allowed insertions=2 and allowed replacements=2, the search succeeds if 2 characters had been inserted and an additional replacement is needed to match. The relaxed algorithm may return false positives, but meets user expectation better.
    """
    WILD_MATCH_SELECTION: Literal[1048576]
    """
    Flag for wildcards search if entire selection must match the pattern.
    
    If com.sun.star.util.SearchOptions2.AlgorithmType2 is com.sun.star.util.SearchAlgorithms2.WILDCARD specifies whether a wildcard pattern must match the entire selected range of the string from start position to end position or a substring match is allowed.
    
    If set, the entire selection must match. If not set, a substring match is allowed.
    
    **since**
    
        LibreOffice 5.2
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text.textfield
from ..text_field import TextField as TextField_90260a56

class InputUser(TextField_90260a56):
    """
    Service Class

    specifies service of an input field that is used to change the content of a corresponding field master of a user defined text field.

    See Also:
        `API InputUser <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1InputUser.html>`_
    """
    @property
    def Content(self) -> str:
        """
        contains the name of the corresponding field master.
        """
    @property
    def Hint(self) -> str:
        """
        contains a hint text.
        
        This hint may be used as help tip or as headline of a corresponding dialog to edit the field content.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.configuration.bootstrap
from ...uno.x_component_context import XComponentContext as XComponentContext_e2e10d4a

class BootstrapContext(XComponentContext_e2e10d4a):
    """
    Service Class

    provides access to a component context that is enhanced with bootstrap parameters for configuration services from the associated metaconfiguration mechanism.
    
    The contained settings are used to initialize the com.sun.star.configuration.DefaultProvider and com.sun.star.configuration.backend.DefaultBackend of the component context.
    
    The implementation is usually available as a singleton in the context that it wraps...
    
    **since**
    
        OOo 1.1.2
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API BootstrapContext <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1bootstrap_1_1BootstrapContext.html>`_
    """


